' OptusNet Usage Monitor v4.5
' Modified by Chucky2k
'
' Original script written by dx and kop48.
' Version 3.0 and 3.1 by Written by RaveRod (raverod@mantrasoftware.net)
'
' History:
'	v1.0 : Original dx script.
'	v2.0b: Modified by kop48 to include average usage.
'	v3.0 : Modified by RaveRod to download page ONCE and then read all information from there.
'	       Added function to get the time that usage was last updated.
'	       Added function to calculate how much usage is left per day (based on the per month function of kop48).
'	v3.1 : Fixed month size check to read end date from Optus Usage file.
'	v4.0 : Modified by Chucky2k to handle new usage.txt layout from optus. copied existing fuctions to read the Offpeak Data 
'	       allowance and usage. Original function names remain unchanged so no Samurize Config file changes will be
'	       needed if you don't want to display Offpeak information. Just set the Usename and Password and your away.
'	v4.1 : Modified Peak Usage as per suggestion by Funkdafied in the forums. Also changed the Get_HTML function as per AdamC
'	       in the forums to fix an issue with updating the usage file.
'	v4.5 : Modified the URL in Get_HTML function to the new address used by optusnet. Also added functions to return the daily usage
'	       left for the current month.

' Configuration.
username = "username"
password = "password"

' Gets the current Peak OptusNet usage.
Function Get_Usage
	contents = Read_File()
	leftMark = instr(instr( contents, "usage=" ) + 1, contents, "usage=" ) 
	leftMark = leftMark +6
	rightMark = instr( leftMark, contents, "MB" )
	Get_Usage = trim(mid( contents, leftMark, (rightMark-leftMark)))
End Function

' Gets the current Off Peak OptusNet usage.
Function Get_UsageOffPeak
	contents = Read_File()
	leftMark = instr( contents, "offpeak_usage=" ) 
	leftMark = leftMark +14
	rightMark = instr( leftMark, contents, "MB" )
	Get_UsageOffPeak = trim(mid( contents, leftMark, (rightMark-leftMark)))
End Function

' Gets the current Peak plan size.
Function Get_PlanSize
	contents = Read_File()
	leftMark = instr( contents, "plan_limit=" ) 
	leftMark = leftMark +11
	rightMark = instr( leftMark, contents, "MB" )
	Get_PlanSize = trim(mid( contents, leftMark, (rightMark-leftMark)))
end function

' Gets the current Off Peak plan size.
Function Get_PlanSizeOffPeak
	contents = Read_File()
	leftMark = instr( contents, "plan_offpeak=" ) 
	leftMark = leftMark +13
	rightMark = instr( leftMark, contents, "MB" )
	Get_PlanSizeOffPeak = trim(mid( contents, leftMark, (rightMark-leftMark)))
end function

' Gets the time when the usage was updated.
Function Get_Time
	contents = Read_File()

	leftMark = instr( contents, "last=" )
	leftMark = leftMark +5

	rightMark = instr( leftMark, contents, "-" )
	LastY = trim(mid( contents, leftMark+2, (rightMark-leftMark-2)))

	leftMark = leftMark + (rightMark-leftMark+1)
	rightMark = instr( leftMark, contents, "-" )
	LastM = trim(mid( contents, leftMark, (rightMark-leftMark)))

	leftMark = leftMark + (rightMark-leftMark+1)
	rightMark = instr( leftMark, contents, " " )
	LastD = trim(mid( contents, leftMark, (rightMark-leftMark)))

	leftMark = leftMark + (rightMark-leftMark+1)
	rightMark = instr( leftMark, contents, ":" )
	LastH = trim(mid( contents, leftMark, (rightMark-leftMark)))
	If LastH > 12 Then
		LastH = LastH -12
		AMPM = "PM"
	ElseIf LastH = 12 Then
		AMPM = "PM"
	Else
		AMPM = "AM"
	End If

	leftMark = leftMark + (rightMark-leftMark+1)
	rightMark = instr( leftMark, contents, ":" )
	LastDay = trim(mid( contents, leftMark, (rightMark-leftMark)))

	leftMark = leftMark + (rightMark-leftMark+1)
	LastMin = trim(mid( contents, leftMark, 2))

	Get_Time = LastH & ":" & LastDay & ":" & LastMin & AMPM & " " & LastD & "." & LastM & "." & LastY
End Function

Function Month_Length
	contents = Read_File()

	leftMark = instr( contents, "end=" )
	leftMark = leftMark +12

	Month_Length = trim(mid( contents, leftMark, 2))
End Function

' Returns Days left in the current month
Function Days_Left
	Dim Current_Day	
	
	Current_Day = Day(Date)
	Days_Left = Month_Length-Current_Day

End Function

' Tells how much usage you have left per day.
Function Calc_Day
	MaxUsage = Calc_Usage()
	CurUsage = Get_Usage()

	CalcUsage = Round(MaxUsage - CurUsage)

	If CalcUsage <= 0 Then
		Stat = " over"
	Else
		Stat = " under"
	End If

	Calc_Day = Replace(CalcUsage, "-", "") & " MB" & Stat
End Function

' Tells how much Off Peak usage you have left per day.
Function Calc_DayOffPeak
	MaxUsage = Calc_UsageOffPeak()
	CurUsage = Get_UsageOffPeak()

	CalcUsage = Round(MaxUsage - CurUsage)

	If CalcUsage <= 0 Then
		Stat = " over"
	Else
		Stat = " under"
	End If

	Calc_DayOffPeak = Replace(CalcUsage, "-", "") & " MB" & Stat
End Function

' This function will calculate what usage you should be at if you divided
' your monthly limit by the number of days in the current month, then 
' multiplying it by the date to give you an approximation. This is handy
' for regulating your bandwidth so that you've got some left at the end 
' of the month. :)
Function Calc_Usage
	contents = Read_File()

	leftMark = instr( contents, "end=" )
	leftMark = leftMark +12
	monthSize = trim(mid( contents, leftMark, 2))

	Calc_Usage = (Get_PlanSize/monthSize) * Day(Date)
End Function

' This function will calculate what Off Peak usage you should be at if you divided
' your monthly limit by the number of days in the current month, then 
' multiplying it by the date to give you an approximation. This is handy
' for regulating your bandwidth so that you've got some left at the end 
' of the month. :)
Function Calc_UsageOffPeak
	contents = Read_File()

	leftMark = instr( contents, "end=" )
	leftMark = leftMark +12
	monthSize = trim(mid( contents, leftMark, 2))

	Calc_UsageOffPeak = (Get_PlanSizeOffPeak/monthSize) * Day(Date)
End Function

' This will return your daily allowance for the rest of the month based on your current usage
Function Daily_Usage_Left

	If Days_Left = 0 Then
		Daily_Usage_Left = (Get_PlanSize - Get_Usage)
	Else
		Daily_Usage_Left = (Get_PlanSize - Get_Usage) / Days_Left
	End If

End Function

' This will return your daily allowance for the rest of the month based on your current usage
Function Daily_Usage_LeftOffPeak

	If Days_Left = 0 Then
		Daily_Usage_LeftOffPeak = (Get_PlanSizeOffPeak - Get_UsageOffPeak)
	Else
		Daily_Usage_LeftOffPeak = (Get_PlanSizeOffPeak - Get_UsageOffPeak) / Days_Left
	End If

End Function

' Get the current usage HTML and write it to a file.
' Note: This function should only be called at intervals of AT LEAST 15 minutes.
Function Get_HTML
	Randomize
	sURL = "https://memberservices.optusnet.com.au/myusage/usage.txt?login=" & username & "&passwd=" & password & "&random=" & Rnd
	Dim objXMLHTTP,HTML
	Set objXMLHTTP = CreateObject("Microsoft.XMLHTTP")
	objXMLHTTP.Open "GET", sURL, False
	objXMLHTTP.Send
	HTML = objXMLHTTP.responseBody
	Set objRS = CreateObject("ADODB.Recordset")
	objRS.Fields.Append "txt", 200, 45000, &H00000080
	objRS.Open
	objRS.AddNew
	objRS.Fields("txt").AppendChunk HTML
	ReturnHTML = objRS("txt").Value
	objRS.Close
	Set objRS = Nothing
	Set objXMLHTTP = Nothing

	Set fs = CreateObject("Scripting.FileSystemObject")
	Set f = fs.CreateTextFile("optususage.txt",true)
	f.write(ReturnHTML)
	f.close
	Set f = Nothing
	Set fs = Nothing
End Function

' Read the contents of the downloaded OptusNet information.
Function Read_File
	Dim contents
	Set fs = CreateObject ("Scripting.FileSystemObject")
	If (fs.FileExists("optususage.txt")) Then
		Set filePath = fs.GetFile("optususage.txt")
		Set File = filePath.OpenAsTextStream (1, -2)
		contents = file.readall
		File.Close
		Set filePath = nothing
		Set fs = nothing
		Set File = nothing
	Else
		Get_HTML()
		Read_File()
	End If

	Read_File = contents
End Function

